import React, { PureComponent } from 'react';
import axios from 'axios';

import PDF from '../../Images/pdficon.png';
import PW from '../../Images/pptxicon.png';



interface UploadState {
    recentImage: any;
    caption: string;
    uploadedImageUrl: string;
    uploadedImage: any;
    imagename: string;
    filetype :string,
    lessonname:string,
    lessonno: string,
};

class UploadPage extends PureComponent<{}, UploadState> {
    constructor(props: {}) {
        super(props);

        this.state = {
            recentImage: {},
            caption: '',
            uploadedImageUrl: '',
            uploadedImage: {},
            imagename : '',
            filetype: '',
            lessonname:'',
            lessonno:'',
        };
    }

    componentDidMount = () => {
        this.fetchRecent();
    }
    componentDidUpdate=()=> {

    }

    fetchRecent = () => {
        axios.get('http://localhost:5000/recent')
            .then((response) => {
                this.setState({ recentImage: response.data.image });
            })
            .catch(err => alert('Error: ' + err));

        if(this.state.filetype==""){
            this.setState({

                filetype :"",
                lessonname:"",
                lessonno:"",
            });
        }
    }

    uploadImage = () => {
        if (!this.state.caption.trim() || !this.state.uploadedImage.name) {
            return alert('Caption or file is missing');
        }

        let formData = new FormData();
        formData.append('caption', this.state.caption);
        formData.append('file', this.state.uploadedImage);
        formData.append('lessonno', this.state.lessonno);
        formData.append('lessonname', this.state.lessonname);

        axios.post('http://localhost:5000/', formData)
            .then((response) => {
                response.data.success ? alert('File successfully uploaded') : alert('File already exists');
                this.fetchRecent();
            })
            .catch(err => alert('Error: ' + err));
    }

    render() {
        return (
            <div className="UploadPage">
                <div className="Recent">






                    <div className="row">
                        <div className="col-sm-5">

                            <label>Lesson No: </label>
                            <div style={{padding: '0px'}}>
                                <select style={{width: '100%'}} className="browser-default custom-select"
                                        value={this.state.lessonno}
                                        onChange={event => this.setState({ lessonno: event.target.value })}>
                                    <option>Select Lesson No</option>
                                    <option>1</option>
                                    <option>2</option>
                                    <option>3</option>
                                    <option>4</option>
                                    <option>5</option>


                                </select>
                            </div>




                        </div>

                        <div className="col-sm-5">

                            <label>Lesson name: </label>
                            <div style={{padding: '0px'}}>
                                <input type="text" required className="form-control"
                                       onChange={event => this.setState({ lessonname: event.target.value })}
                                       value={this.state.lessonname}/>
                            </div>
                        </div>
                    </div>

                    <div className="row">
                        <div className="col-sm-5">
                            <label>Lesson caption: </label>
                            <div style={{padding: '0px'}}>
                                <input
                                    type="text"
                                    className="form-control"
                                    placeholder="Enter caption..."
                                    onChange={event => this.setState({ caption: event.target.value })}
                                    value={this.state.caption}
                                />
                            </div>
                        </div>

                        <div className="col-sm-5">
                            <label>Upload file: </label>
                            <div style={{padding: '0px'}}>
                                <input
                                    type="file"
                                    className="Upload__Input"
                                    onChange={(event: any) => {
                                        this.setState({
                                            uploadedImageUrl: URL.createObjectURL(event.target.files[0]),
                                            uploadedImage: event.target.files[0],
                                        })
                                    }}
                                />
                            </div>


                        </div>
                    </div>



                    <div className="row">

                        <div className="col-sm-10">


                            <button  type ="submit" value ="Submit"
                                     className = "btn btn-block btn-success mt-3" onClick={this.uploadImage}>  ADD
                            </button>

                        </div>
                    </div>
                </div>

                <br/><br/>

                <div className="border">
                    <div className="text-left" style={{margin: "15px"}}>
                        <h5 className="text-left"> Recent Upload File </h5>
                        <p>Filename      : {this.state.recentImage.filename}</p>
                        <p>Lesson Name   : {this.state.recentImage.lessonname}</p>
                        <p>Lesson Number : {this.state.recentImage.lessonno}</p>

                    </div>

                </div>

            </div>
        );
    }
}

export default UploadPage;

